==> kit-vue-1.16.12.tgz: package/src/stories/ShPageHeader.stories.js <==
import {storiesOf} from '@storybook/vue'
import ShPageHeader from '../components/sh-page-header/ShPageHeader';
import { ShButton, ShButtonGroup } from '../components/sh-button';
import ShIcon from '../components/sh-icon/ShIcon';
import {boolean, select, text, withKnobs} from "@storybook/addon-knobs";
const stories = storiesOf('Page headers', module);

stories.addDecorator(withKnobs);
stories.add('Settings page', () => ({
  components: {ShPageHeader, ShButton, ShButtonGroup},
  data: () => {
    return {
      alignmentLeftClass: text('alignmentLeftClass', 'sm-12 md-6 column'),
      alignmentRightClass: text('alignmentLeftClass', 'sm-12 md-6 column'),
      hasMobileMenu: boolean('hasMobileMenu', true),
      orderOfElements: text('orderOfElements', 'tbb'),
    }
  },
  template: `<ShPageHeader :hasMobileMenu="hasMobileMenu" :orderOfElements="orderOfElements">
<h2 slot="page_header_left">Page title</h2>
<ShButtonGroup align="right" slot="page_header_right">
 <ShButton
  buttonColor="icon-outline-blue"
  buttonIcon="sh-icon-help"
  buttonSize="small"
  :isIcon="true"
  ></ShButton>
  <ShButton
  buttonColor="icon-outline-blue"
  buttonIcon="sh-icon-search"
  buttonSize="small"
  :isIcon="true"
  ></ShButton>
</ShButtonGroup>
</ShPageHeader>`,
}),{
  notes: 'A very very simple component',
});

stories.add('Product page', () => ({
  components: {ShPageHeader, ShButton, ShButtonGroup},
  data: () => {
    return {
      alignmentLeftClass: text('alignmentLeftClass', 'sm-6 md-3 column'),
      alignmentCenterClass: text('alignmentCenterClass', 'sm-12 md-6 column'),
      alignmentRightClass: text('alignmentRightClass', 'sm-6 md-3 column'),
      noHamburgerPage: text('noHamburgerPage', 'sh-no-hamburger-page'),
      hasMobileMenu: boolean('hasMobileMenu', false),
      orderOfElements: text('orderOfElements', 'btb'),
    }
  },
  template: `<ShPageHeader 
:orderOfElements="orderOfElements"
:alignmentLeftClass="alignmentLeftClass" 
:alignmentCenterClass="alignmentCenterClass" 
:alignmentRightClass="alignmentRightClass"
:noHamburgerPage="noHamburgerPage"
:hasMobileMenu="hasMobileMenu">
<ShButton
slot="page_header_left"
buttonContent="Back"
buttonColor="secondary"
buttonIcon="sh-icon-arrow-back"
buttonSize="small"
:isIconLeft="true"
></ShButton>
<div slot="page_header_center">
<h2 class="link-under-name">
    Product name
</h2>
</div>
<ShButtonGroup align="right" slot="page_header_right">
  <ShButton
  buttonColor="icon-outline-blue"
  buttonIcon="sh-icon-help"
  buttonSize="small"
  :isIcon="true"
  ></ShButton>
  <ShButton
  buttonColor="icon-outline-blue"
  buttonIcon="sh-icon-search"
  buttonSize="small"
  :isIcon="true"
  ></ShButton>
</ShButtonGroup>
</ShPageHeader>`,
}),{
  notes: 'A very very simple component',
});

==> kit-vue-2.3.8.tgz: package/src/stories/ShPageHeader.stories.js <==
import {storiesOf} from '@storybook/vue'
import ShPageHeader from '../components/sh-page-header/ShPageHeader';
import { ShButton, ShButtonGroup } from '../components/sh-button';
import ShIcon from '../components/sh-icon/ShIcon';
import {boolean, select, text, withKnobs} from "@storybook/addon-knobs";
const stories = storiesOf('Page headers', module);

stories.addDecorator(withKnobs);
stories.add('Settings page', () => ({
  components: {ShPageHeader, ShButton, ShButtonGroup},
  props: {
    alignmentLeftClass: { default: text('alignmentLeftClass', 'sm-12 md-6 column') },
    alignmentRightClass: { default: text('alignmentLeftClass', 'sm-12 md-6 column') },
    hasMobileMenu: { default: boolean('hasMobileMenu', true) },
    orderOfElements: { default: text('orderOfElements', 'tbb') },
  },
  template: `<ShPageHeader :hasMobileMenu="hasMobileMenu" :orderOfElements="orderOfElements">
<h2 slot="page_header_left">Page title</h2>
<ShButtonGroup align="right" slot="page_header_right">
 <ShButton
  buttonColor="icon-outline-blue"
  buttonIcon="sh-icon-help"
  buttonSize="small"
  :isIcon="true"
  ></ShButton>
  <ShButton
  buttonColor="icon-outline-blue"
  buttonIcon="sh-icon-search"
  buttonSize="small"
  :isIcon="true"
  ></ShButton>
</ShButtonGroup>
</ShPageHeader>`,
}),{
  notes: 'A very very simple component',
});

stories.add('Product page', () => ({
  components: {ShPageHeader, ShButton, ShButtonGroup},
  props: {
      alignmentLeftClass: { default: text('alignmentLeftClass', 'sm-6 md-3 column') },
      alignmentCenterClass: { default: text('alignmentCenterClass', 'sm-12 md-6 column') },
      alignmentRightClass: { default: text('alignmentRightClass', 'sm-6 md-3 column') },
      noHamburgerPage: { default: text('noHamburgerPage', 'sh-no-hamburger-page') },
      hasMobileMenu: { default: boolean('hasMobileMenu', false) },
      orderOfElements: { default: text('orderOfElements', 'btb') },
  },
  template: `<ShPageHeader 
:orderOfElements="orderOfElements"
:alignmentLeftClass="alignmentLeftClass" 
:alignmentCenterClass="alignmentCenterClass" 
:alignmentRightClass="alignmentRightClass"
:noHamburgerPage="noHamburgerPage"
:hasMobileMenu="hasMobileMenu">
<ShButton
slot="page_header_left"
buttonContent="Back"
buttonColor="secondary"
buttonIcon="sh-icon-arrow-back"
buttonSize="small"
:isIconLeft="true"
></ShButton>
<div slot="page_header_center">
<h2 class="link-under-name">
    Product name
</h2>
</div>
<ShButtonGroup align="right" slot="page_header_right">
  <ShButton
  buttonColor="icon-outline-blue"
  buttonIcon="sh-icon-help"
  buttonSize="small"
  :isIcon="true"
  ></ShButton>
  <ShButton
  buttonColor="icon-outline-blue"
  buttonIcon="sh-icon-search"
  buttonSize="small"
  :isIcon="true"
  ></ShButton>
</ShButtonGroup>
</ShPageHeader>`,
}),{
  notes: 'A very very simple component',
});
